# Gomyck-Tools

## project

https://github.com/mzxc

## install

This package need python version >= 3.9

```shell
pip install gomyck-tools
```

## usage

```python
from ctools import sys_log
sys_log.clog.info('hello world')
```


